@@ -20,11 +20,14 @@ import (
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/transport"
 
+	addonclientset "github.com/open-cluster-management/api/client/addon/clientset/versioned"
 	clusterclientset "github.com/open-cluster-management/api/client/cluster/clientset/versioned"
 	workclientset "github.com/open-cluster-management/api/client/work/clientset/versioned"
 	clusterv1 "github.com/open-cluster-management/api/cluster/v1"
+	"github.com/open-cluster-management/registration/pkg/clientcert"
 	"github.com/open-cluster-management/registration/pkg/hub"
-	"github.com/open-cluster-management/registration/pkg/spoke/hubclientcert"
+	"github.com/open-cluster-management/registration/pkg/spoke"
+	"github.com/open-cluster-management/registration/pkg/spoke/addon"
 	"github.com/open-cluster-management/registration/pkg/spoke/managedcluster"
 	"github.com/open-cluster-management/registration/test/integration/util"
 
@@ -47,6 +50,7 @@ var securePort int
 
 var kubeClient kubernetes.Interface
 var clusterClient clusterclientset.Interface
+var addOnClient addonclientset.Interface
 var workClient workclientset.Interface
 
 var testNamespace string
@@ -65,9 +69,13 @@ var _ = ginkgo.BeforeSuite(func(done ginkgo.Done) {
 
 	// crank up the sync speed
 	transport.CertCallbackRefreshDuration = 5 * time.Second
-	hubclientcert.ControllerSyncInterval = 5 * time.Second
+	clientcert.ControllerResyncInterval = 5 * time.Second
 	managedcluster.CreatingControllerSyncInterval = 1 * time.Second
 
+	// crank up the addon lease sync and udpate speed
+	spoke.AddOnLeaseControllerSyncInterval = 5 * time.Second
+	addon.AddOnLeaseControllerLeaseDurationSeconds = 1
+
 	// install cluster CRD and start a local kube-apiserver
 
 	err = util.GenerateSelfSignedCertKey()
@@ -83,9 +91,8 @@ var _ = ginkgo.BeforeSuite(func(done ginkgo.Done) {
 	testEnv = &envtest.Environment{
 		ErrorIfCRDPathMissing: true,
 		CRDDirectoryPaths: []string{
-			filepath.Join(".", "vendor", "github.com", "open-cluster-management", "api", "cluster", "v1"),
-			filepath.Join(".", "vendor", "github.com", "open-cluster-management", "api", "cluster", "v1alpha1"),
-			filepath.Join(".", "vendor", "github.com", "open-cluster-management", "api", "work", "v1"),
+			filepath.Join(".", "deploy", "hub"),
+			filepath.Join(".", "deploy", "spoke"),
 		},
 		KubeAPIServerFlags: apiServerFlags,
 	}
@@ -118,6 +125,10 @@ var _ = ginkgo.BeforeSuite(func(done ginkgo.Done) {
 	gomega.Expect(err).ToNot(gomega.HaveOccurred())
 	gomega.Expect(clusterClient).ToNot(gomega.BeNil())
 
+	addOnClient, err = addonclientset.NewForConfig(cfg)
+	gomega.Expect(err).ToNot(gomega.HaveOccurred())
+	gomega.Expect(clusterClient).ToNot(gomega.BeNil())
+
 	workClient, err = workclientset.NewForConfig(cfg)
 	gomega.Expect(err).ToNot(gomega.HaveOccurred())
 	gomega.Expect(clusterClient).ToNot(gomega.BeNil())
